@@ -256,6 +256,18 @@ void SCWind::on_pb_prefer_slabs_clicked() noexcept {
           -> int { return impl_select_blk_by_id(blks, "_slab"); });
 }
 
+void SCWind::on_pb_prefer_carpets_clicked() noexcept {
+  this->ui->blm->select_block_by_callback(
+      [](const std::vector<const SlopeCraft::mc_block_interface *> &blks)
+          -> int { return impl_select_blk_by_id(blks, "_carpet"); });
+}
+
+void SCWind::on_pb_prefer_pressure_plates_clicked() noexcept {
+  this->ui->blm->select_block_by_callback(
+      [](const std::vector<const SlopeCraft::mc_block_interface *> &blks)
+          -> int { return impl_select_blk_by_id(blks, "_pressure_plate"); });
+}
+
 void SCWind::on_pb_select_all_clicked() noexcept {
   for (size_t bc = 0; bc < this->ui->blm->num_basecolor_widgets(); bc++) {
     this->ui->blm->basecolorwidget_at(bc)->set_enabled(true);
@@ -359,13 +371,14 @@ void SCWind::on_pb_save_converted_clicked() noexcept {
         goto save_image;
       }
 
-      auto ret = QMessageBox::warning(
+      const auto ret = QMessageBox::warning(
           this, tr("将要覆盖已存在的图像"),
           tr("%1将被覆盖，确认覆盖吗？").arg(filename),
           QMessageBox::StandardButtons{QMessageBox::StandardButton::Yes,
                                        QMessageBox::StandardButton::No,
                                        QMessageBox::StandardButton::YesToAll,
                                        QMessageBox::StandardButton::NoToAll});
+
       bool replace;
       switch (ret) {
         case QMessageBox::StandardButton::Yes:
@@ -384,7 +397,7 @@ void SCWind::on_pb_save_converted_clicked() noexcept {
           break;
       }
 
-      if (!replace) {
+      if (not replace) {
         continue;
       }
     }
@@ -695,13 +708,30 @@ void SCWind::on_pb_export_file_clicked() noexcept {
     }
 
     if (exisiting_num > 0) {
-      const auto ret = QMessageBox::warning(
-          this, tr("%1 个文件将被替换").arg(exisiting_num),
-          tr("以下文件将被替换：\n%1\n点击 Yes "
-             "将替换它们，点击 No 将取消这次导出。")
-              .arg(to_be_replaced),
-          QMessageBox::StandardButtons{QMessageBox::StandardButton::Yes,
-                                       QMessageBox::StandardButton::No});
+      QMessageBox msg_box{this};
+      {
+        msg_box.setStandardButtons(QMessageBox::StandardButtons{
+            QMessageBox::StandardButton::Yes, QMessageBox::StandardButton::No});
+        msg_box.setWindowTitle(tr("%1 个文件将被替换").arg(exisiting_num));
+        msg_box.setText(
+            tr("%1 个文件将被替换。点击 Show Details 可以查看它们。\n点击 Yes "
+               "将替换它们，点击 No 将取消这次导出。")
+                .arg(exisiting_num));
+        msg_box.setDetailedText(to_be_replaced);
+        // Click the button "Show Detail". If not found, let it go
+        for (QAbstractButton *abtn : msg_box.buttons()) {
+          QPushButton *btn = dynamic_cast<QPushButton *>(abtn);
+          if (not btn) [[unlikely]] {
+            continue;
+          }
+          const auto str = btn->text().toLower();
+          if (str.contains("detail")) {
+            emit btn->click();
+            break;
+          }
+        }
+      }
+      const auto ret = msg_box.exec();
 
       if (ret != QMessageBox::StandardButton::Yes) {
         return;
